==> pdf_slideshow-8.x-1.0.tar.gz: pdf_slideshow/src/Gateway/PdfSlideshowEntityGateway.php <==
<?php

namespace Drupal\pdf_slideshow\Gateway;

use Drupal\Core\Entity\EntityTypeManager;

class PdfSlideshowEntityGateway {

  protected $entityTypeManager;

  /**
   * PdfSlideshowEntityGateway constructor.
   *
   * @param $entityTypeManager
   */
  public function __construct(EntityTypeManager $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Create file entity.
   *
   * @param array $filePaths
   *
   * @return array|null|
   *   File entity ids.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function createFileEntities(array $filePaths) {
    if ($filePaths) {
      $fids = [];
      foreach ($filePaths as $filePath) {
        $fileEntity = $this->entityTypeManager->getStorage('file')->create([
          'uri' => $filePath,
          'status' => FILE_STATUS_PERMANENT,
        ]);
        $fileUri = $fileEntity->get('uri')->getValue()[0]['value'];
        $fileEntity->set('uri', $fileUri);
        $fileEntity->save();
        $fids[] = $fileEntity->id();
      }
      return $fids;
    }
    return NULL;
  }

  /**
   * Get pdf file image urls.
   *
   * @param array $fids
   *
   * @return array|null
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function getPdfFileImageUrls(array $fids) {
    $files = $this->entityTypeManager
      ->getStorage('file')
      ->loadMultiple($fids);
    $fileUrls = [];
    foreach ($files as $file) {
      $url = str_replace($_SERVER['DOCUMENT_ROOT'] . '/', '',
        $file->getFileUri());
      $fileUrls[] = $url;
    }
    return $fileUrls ? $fileUrls : NULL;
  }

}

==> pdf_slideshow-8.x-1.3.tar.gz: pdf_slideshow/src/Gateway/PdfSlideshowEntityGateway.php <==
<?php

namespace Drupal\pdf_slideshow\Gateway;

use Drupal\Core\Entity\EntityTypeManager;

class PdfSlideshowEntityGateway {

  protected $entityTypeManager;

  /**
   * PdfSlideshowEntityGateway constructor.
   *
   * @param $entityTypeManager
   */
  public function __construct(EntityTypeManager $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Create file entity from unmanaged image files.
   *
   * @param array $filePaths
   *
   * @return array|null|
   *   File entity ids.
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function createFileEntities(array $filePaths) {
    if ($filePaths) {
      $fids = [];
      foreach ($filePaths as $filePath) {
        $fileEntity = $this->entityTypeManager->getStorage('file')->create([
          'uri' => $filePath,
          'status' => FILE_STATUS_PERMANENT,
        ]);
        $fileUri = $fileEntity->get('uri')->getValue()[0]['value'];
        $fileEntity->set('uri', $fileUri);
        $fileEntity->save();
        $fids[] = $fileEntity->id();
      }
      return $fids;
    }
    return NULL;
  }

  /**
   * Get pdf file image urls from field ids.
   *
   * @param array $fids
   *
   * @return array|null
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function getPdfFileImageUrls(array $fids) {
    $files = $this->entityTypeManager
      ->getStorage('file')
      ->loadMultiple($fids);
    $fileUrls = [];
    foreach ($files as $file) {
      $url = str_replace($_SERVER['DOCUMENT_ROOT'] . '/', '',
        $file->getFileUri());
      $fileUrls[] = $url;
    }
    return $fileUrls ? $fileUrls : NULL;
  }

  /**
   * Get file entity from file ids.
   *
   * @param array $fileIds
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function getFileEntities(array $fileIds) {
    return $this->entityTypeManager
      ->getStorage('file')
      ->loadMultiple($fileIds);
  }

}
